function n = countunstable(A)
% Returns the number of eigenvalues with positive real part.
% If A is a matrix of intervals, then the number is rigorous.
% And NaN is returned when a conclusion cannot be reached.

if exist('intval','file') && isintval(A(1))
    [V,~]=eig(mid(A));
    V=intval(V);
else
    [V,~]=eig(A);
end
% exact enclosure of the matrix in case of interval arithmetic
W=inv(V);
% B and A are similar matrices and B is almost diagonal
B=W*A*V;
D=real(diag(B));
E=B;
E(eye(size(E))==1)=0;
E=sum(abs(E),2);
% use Gershgorin circles
n=length(find(D-E>0));
m=length(find(D+E<0));

if ~(n+m==length(D))
    n=NaN;
end

end
