function mul = multiplicity(c,rmin,rmax,nu,lambda)
% determines how many nonequivalent solutions there are 
% under the symmetry group

if exist('intval','file') && isintval(lambda)
    rmin=intval(rmin);
    rmax=intval(rmax);
    nu=intval(nu);
    c=intval(c);
end

nc=size(c)-1;
[kx,ky]=ndgrid(0:nc(1),0:nc(2));

% construct the weights in the norm
multi=4*ones(size(kx));
multi(kx==0)=multi(kx==0)/2;
multi(ky==0)=multi(ky==0)/2;
weights=multi.*nu.^(max(abs(kx),abs(ky)));

same=false(16,1); % used to flag stabilizer
different=false(16,1); % used to flag other elements of group orbit 
undecided=false(16,1); % used to flag failure

for j=0:15
  % there are 16 elements in the symmetry group
  jj=dec2bin(j,4);
  cc=c;
  if jj(1)=='1'
     % flip along the x-axis 
     cc=cc.*(-1).^(kx);
  end
  if jj(2)=='1'
     % flip along the y-axis 
     cc=cc.*(-1).^(ky);
  end
  if jj(3)=='1'   
      % flip the x and y axes
      cc=permute(cc,[2,1]);
  end
  if jj(4)=='1'
      % u -> -u
      cc=-cc;
  end
  diffc=c-cc;
  % distance between c and its symmetry related cc
  r0=sum(abs(diffc(:)).*weights(:));
  if r0+2*rmin<rmax
      % solution corresponding to cc is within the uniqueness radius of c
      same(j+1)=true;
  elseif r0>2*rmin
      % existence balls for c and cc are disjoint
      different(j+1)=true;
  else
      undecided(j+1)=true;
  end
end
if ~any(undecided)
    % orbit-stabilizer theorem
    mul=16/sum(same);  
else
    % no success
    mul=NaN;
end
end
