% script that attempts to prove equilibria for lambda=12

% number of solutions on primary branches
totalsol=15;
% success vector
S=false([1,totalsol]);
% Morse indices
M=zeros([1,totalsol]);
% rmin
rminall=zeros([1,totalsol]);

% computational constants
nu=1.00000001;
nmodes=20;

for k=1:totalsol

    % get data
    load(['data12/sol',int2str(k)]);
    lambda=12;
    % pad with zeros
    nc=[nmodes,nmodes];
    c=zeros(nc+1);
    c(1:n(1)+1,1:n(2)+1)=reshape(b,n+1);
    % improve numerical solution
    c=newtoniterate(c(:),lambda,nc);
    % we want a real proof
    lambda=intval(lambda);
    [s,rmin,rmax,morse]=proveit(c,lambda,nc,nu);
    S(k)=s;
    M(k)=morse;
    rminall(k)=rmin;

    % find multiplicity
    mul=multiplicity(reshape(c,nc+1),rmin,rmax,nu,lambda);
    disp(['multiplicity is ',int2str(mul)]);

    % plot
    fig=figure(5);
    plotcos2d(c,nc);
    xlabel('$$x_1$$', 'Interpreter', 'latex', 'FontSize', 14)
    ylabel('$$x_2$$', 'Interpreter', 'latex', 'FontSize', 14)
    zlabel('$$u$$', 'Interpreter', 'latex', 'FontSize', 14)
    xticks(0:3)
    yticks(0:3)
    t=title(['index ',int2str(morse),'   -   multiplicity ',int2str(mul)]);
    t.FontSize = 14;
    drawnow
    fig.PaperSize=[18 14];
    fig.PaperUnits='centimeters'; 
    print(['figures/sol12no',int2str(k)],'-dpdf','-r400')

end

% number of solutions on secondary branches
totalbif=5;
% success vector
Sb=false([1,totalbif]);
% Morse indices
Mb=zeros([1,totalbif]);
% rmin
rminallb=zeros([1,totalbif]);

% computational constants
nu=1.00000001;
nmodes=20;

for k=1:totalbif

    % get data
    load(['data12/solbif',int2str(k)]);
    lambda=12;
    % pad with zeros
    nc=[nmodes,nmodes];
    c=zeros(nc+1);
    c(1:n(1)+1,1:n(2)+1)=reshape(b,n+1);
    % improve numerical solution
    c=newtoniterate(c(:),lambda,nc);
    % we want a real proof
    lambda=intval(lambda);
    [s,rmin,rmax,morse]=proveit(c,lambda,nc,nu);
    Sb(k)=s;
    Mb(k)=morse;
    rminallb(k)=rmin;

    % find multiplicity
    mul=multiplicity(reshape(c,nc+1),rmin,rmax,nu,lambda);
    disp(['multiplicity is ',int2str(mul)]);    

    % plot
    fig=figure(5);
    plotcos2d(c,nc);
    xlabel('$$x_1$$', 'Interpreter', 'latex', 'FontSize', 14)
    ylabel('$$x_2$$', 'Interpreter', 'latex', 'FontSize', 14)
    zlabel('$$u$$', 'Interpreter', 'latex', 'FontSize', 14)
    xticks(0:3)
    yticks(0:3)
    t=title(['index ',int2str(morse),'   -   multiplicity ',int2str(mul)]);
    t.FontSize = 14;
    drawnow
    fig.PaperSize=[18 15];
    fig.PaperUnits='centimeters'; 
    if ~(k==3) % duplicate for lambda=12 don't store
        print(['figures/sol12bif',int2str(k)],'-dpdf','-r400')
    end

end

disp(['Success vector primary: ',int2str(S)]);
disp(['Success vector secondary: ',int2str(Sb)]);
maxrmin=max([rminall(S),rminallb(Sb)]);
disp(['maximal error bound is ',num2str(maxrmin)]);

